@@ -8,13 +8,13 @@ from .models import Video
 from video_encoding import tasks
 from .tasks import create_thumbnail
 
-#@receiver(post_save, sender=Video)
-#def convert_video(sender, instance, **kwargs):
-#    logger.info('convert_video signal called')
-#    enqueue(tasks.convert_all_videos,
-#            instance._meta.app_label,
-#            instance._meta.model_name,
-#            instance.pk)
+@receiver(post_save, sender=Video)
+def convert_video(sender, instance, **kwargs):
+    logger.info('convert_video signal called')
+    enqueue(tasks.convert_all_videos,
+            instance._meta.app_label,
+            instance._meta.model_name,
+            instance.pk)
 
 @receiver(post_save, sender=Video)
 def thumbnail_signal(sender, instance, **kwargs):
